# Jupyter Tldraw

[![PyPI version](https://img.shields.io/pypi/v/tldraw.svg)](https://pypi.org/project/tldraw/)
[![lite-badge](https://jupyterlite.rtfd.io/en/latest/_static/badge.svg)](https://kolibril13.github.io/jupyter-tldraw/lab/?path=example_notebook.ipynb)



This project brings the very good free whiteboard https://github.com/tldraw/tldraw-v1 into the jupyter output.

Based on ipyreact and tldraw-v1.  
Currenlty experimental.  
The latest tldraw-v2 (https://github.com/tldraw/tldraw) is not support because of this issue: https://github.com/kolibril13/jupyter-tldraw/issues/9

Installation:
```
python3.11 -m venv .venv
pip install jupyterlab
pip install tldraw
jupyterlab   (or alternative VS Code Jupyter Lab)
```



# Changelog

## 0.1.1

* add update_plot in TldrawMatplotlib

## 0.1.0

* Added TldrawMatplotlib

## 0.0.3

* refactor readme
* add jupyterlite demo
## 0.0.2

* refactor code

## 0.0.1

* init setup